<?php namespace Myriad\Carmen;

use GuzzleHttp\Client as Guzzle;
use Illuminate\Contracts\Cache\Repository;

class CarmenConfiguration {

  /**
   * @var array Holds the configuration
   */
  private $config;

  /**
   * @var \GuzzleHttp\Client The Carmen client used for zip to latlng conversion.
   */
  private $guzzle;

  /**
   * Create a new Carmen Configuration Manager
   *
   * @param array $config
   * @param \GuzzleHttp\Client $guzzle
   */
  public function __construct($config, Guzzle $guzzle) {

    // load server token
    if (empty($config['geotools_token'])) {
      throw new \InvalidArgumentException('Configuration must contain server_token');
    }

    // load server url
    if (empty($config['geotools_url'])) {
      throw new \InvalidArgumentException('Configuration must contain server_url');
    }

    $this->config = $config;
    $this->guzzle = $guzzle;
  }

  /**
   * @return string the server token
   */
  public function getServerToken() {
    return $this->config['geotools_token'];
  }

  /**
   * @return string the Carmen server url
   */
  public function getServerUrl() {
    return $this->config['geotools_url'];
  }

}